|License LGPL-3| | |PyPi Package| | |PyPi Versions|

|Build Status| | |Test Coverage| | |Code Climate|

==========
Python OCA
==========

This library contains helpers for Odoo developers, such as:

* ``oca.decorators.foreach`` - A replacement for the deprecated ``odoo.api.one``

Installation
============

Install this package into your Odoo environment.

Using Pip:

   pip install oca-decorators

Using Git:

   git clone https://github.com/OCA/oca-decorators
   python oca-decorators/setup.py install


Setup
=====

Usage
=====

* `Read The API Documentation <https://oca.github.io/oca-decorators>`_

Known Issues / Road Map
=======================


Credits
=======

Images
------

Contributors
------------

* Dave Lasley <dave@laslabs.com>

Maintainer
----------

.. image:: https://odoo-community.org/logo.png
   :alt: Odoo Community Association
   :target: https://odoo-community.org

This library is maintained by the OCA.

OCA, or the Odoo Community Association, is a nonprofit organization whose
mission is to support the collaborative development of Odoo features and
promote its widespread use.

To contribute to this module, please visit https://odoo-community.org.

.. |Build Status| image:: https://img.shields.io/travis/OCA/oca-decorators/master.svg
   :target: https://travis-ci.org/OCA/oca-decorators
.. |Test Coverage| image:: https://img.shields.io/codecov/c/github/OCA/oca-decorators/master.svg
   :target: https://codecov.io/gh/OCA/oca-decorators
.. |Code Climate| image:: https://img.shields.io/codeclimate/github/OCA/oca-decorators.svg
   :target: https://codeclimate.com/github/OCA/oca-decorators
.. |License LGPL-3| image:: https://img.shields.io/github/license/OCA/oca-decorators.svg
   :target: http://www.gnu.org/licenses/lgpl
   :alt: License: LGPL-3
.. |PyPi Package| image:: https://img.shields.io/pypi/v/oca-decorators.svg
   :target: https://pypi.python.org/pypi/oca-decorators
   :alt: PyPi Package
.. |PyPi Versions| image:: https://img.shields.io/pypi/pyversions/oca-decorators.svg
   :target: https://pypi.python.org/pypi/oca-decorators
   :alt: PyPi Versions
